@@ -1,7 +1,7 @@
 package Sort::Sub::ascii_then_num;
 
-our $DATE = '2016-02-25'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-02-27'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010;
 use strict;
@@ -20,8 +20,8 @@ sub gen_sorter {
         no strict 'refs';
 
         my $caller = caller();
-        my $a = ${"$caller\::a"};
-        my $b = ${"$caller\::b"};
+        my $a = @_ ? $_[0] : ${"$caller\::a"};
+        my $b = @_ ? $_[1] : ${"$caller\::b"};
 
         my $cmp = 0;
         if ($a =~ $re_is_num) {
@@ -57,7 +57,7 @@ Sort::Sub::ascii_then_num - Sort non-numbers (sorted asciibetically) before numb
 
 =head1 VERSION
 
-This document describes version 0.04 of Sort::Sub::ascii_then_num (from Perl distribution Sort-Sub), released on 2016-02-25.
+This document describes version 0.05 of Sort::Sub::ascii_then_num (from Perl distribution Sort-Sub), released on 2016-02-27.
 
 =for Pod::Coverage ^(gen_sorter)$
 
