@@ -1,7 +1,7 @@
 package Sort::Sub::naturally;
 
-our $DATE = '2016-02-25'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-02-27'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010;
 use strict;
@@ -16,8 +16,8 @@ sub gen_sorter {
         no strict 'refs';
 
         my $caller = caller();
-        my $a = ${"$caller\::a"};
-        my $b = ${"$caller\::b"};
+        my $a = @_ ? $_[0] : ${"$caller\::a"};
+        my $b = @_ ? $_[1] : ${"$caller\::b"};
 
         my @a_parts = +($is_ci ? lc($a) : $a) =~ /$re/g;
         my @b_parts = +($is_ci ? lc($b) : $b) =~ /$re/g;
@@ -56,7 +56,7 @@ Sort::Sub::naturally - Sort naturally
 
 =head1 VERSION
 
-This document describes version 0.04 of Sort::Sub::naturally (from Perl distribution Sort-Sub), released on 2016-02-25.
+This document describes version 0.05 of Sort::Sub::naturally (from Perl distribution Sort-Sub), released on 2016-02-27.
 
 =for Pod::Coverage ^(gen_sorter)$
 
